from importlib.metadata import version

__version__ = version("dacy")
__title__ = "dacy"
__download_url__ = "https://github.com/centre-for-humanities-computing/DaCy"
